pub struct AtomicLinkedList<T> {
    head_ptr: Option<NonNullSendPtr<ListNode<T>>>,
}

Fields

head_ptr: Option<NonNullSendPtr<ListNode<T>>>

This field could be an AtomicPtr<ListNode<T>>, but in all our use cases, the head is modified without contention, so we make it typed non-atomic.

Implementations

source

impl<T> AtomicLinkedList<T>

source

pub fn from_elems(elems: impl Iterator<Item = T>) -> Self

source

pub fn head_node_ptr(&self) -> Option<NonNullSendPtr<ListNode<T>>>

source

pub fn set_head_node_ptr_noncontested( &mut self, new_head_ptr: Option<NonNullSendPtr<ListNode<T>>> )

source

pub fn push_head_node_noncontested( &mut self, new_head_own: Box<ListNode<T>> ) -> NonNullSendPtr<ListNode<T>>

source

pub fn snap(&self) -> ListSnapshot<T>